// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.math.MathUtil;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.Commands;
import edu.wpi.first.wpilibj2.command.RunCommand;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.command.AlgueExpire;
import frc.robot.command.CoralAlgueInspire;
import frc.robot.command.CoralExpire;
import frc.robot.command.Depart;
import frc.robot.command.DepartPince;
import frc.robot.command.ElevateurManuel;
import frc.robot.command.L2;
import frc.robot.command.L3;
import frc.robot.command.L4;
import frc.robot.command.StationPince;
import frc.robot.subsystems.Elevateur;
import frc.robot.subsystems.Pince;

public class RobotContainer {
  CommandXboxController manette1 = new CommandXboxController(0);
  CommandXboxController manette2 = new CommandXboxController(0);
  Pince pince = new Pince();
  Elevateur elevateur = new Elevateur();
  ElevateurManuel elevateurManuel = new ElevateurManuel(elevateur, manette2::getLeftY);
  public RobotContainer() {
    configureBindings();
    elevateur.setDefaultCommand(new RunCommand(()->{
      elevateur.vitesse(MathUtil.applyDeadband(manette2.getLeftY(), 0.2));
    }, elevateur));
  }

  private void configureBindings() {
    manette1.a().whileTrue(new AlgueExpire(pince));
    manette1.b().whileTrue(new CoralAlgueInspire(pince));
    manette1.x().whileTrue(new CoralExpire(pince));
    manette1.y().whileTrue(new CoralExpire(pince));
    manette1.povUp().toggleOnTrue(new L4(elevateur, pince));
    manette1.povRight().toggleOnTrue(new L2(elevateur, pince));
    manette1.povLeft().toggleOnTrue(new L3(elevateur, pince));
    manette1.povDown().toggleOnTrue(new Depart(elevateur, pince));
    manette2.leftBumper().toggleOnTrue(new DepartPince(pince));
    manette2.a().whileTrue(new StationPince(pince));
  }

  public Command getAutonomousCommand() {
    return Commands.print("No autonomous command configured");
  }
}
